@@ -30,15 +30,9 @@ import itertools
 import socketserver
 import xmlrpc.server
 
-from pyrois import RoIS_HRI, RoIS_Common, RoIS_Service
+from pyrois import RoIS_HRI, RoIS_Common, RoIS_Service, IF_server
 from . import message_profile, Service_Application_Base_sample, HRI_Engine_client_sample
 
-class ThreadingXMLRPCServer(socketserver.ThreadingMixIn, xmlrpc.server.SimpleXMLRPCServer):
-    """ThreadingXMLRPCServer
-    """
-    pass
-
-
 class SystemIF(RoIS_HRI.SystemIF):
     """SystemIF
     """
@@ -721,7 +715,7 @@ class IF(SystemIF, CommandIF, QueryIF, EventIF, Service_Application_Base_sample.
         self.sub_engine = {}
         self.component_client = {}
         event_occur_component = ['PersonDetection','PersonLocalization','PersonIdentification','FaceDetection','FaceLocalization',
-                                'SoundDetection','SoundLocalization','SpeechRecognition','GestureRecognition','VirtualNavigation']
+                                'SoundDetection','SoundLocalization','SpeechRecognition','GestureRecognition']
 
         with open("{}.json".format(client_info),"r") as f:
             d = json.load(f)
@@ -913,24 +907,6 @@ class IF(SystemIF, CommandIF, QueryIF, EventIF, Service_Application_Base_sample.
             return True
 
 
-class IF_server:
-    """IF_Server
-    """
-    def __init__(self, port):
-        self._addr = os.getenv("HRIENGINE")
-        self._server = ThreadingXMLRPCServer(
-            ("0.0.0.0", port), logRequests=False)
-
-    def run(self, _IF):
-        """IF_Server
-        """
-        self._server.register_instance(_IF)
-        self._server.register_introspection_functions()
-        # print("server running")
-        self._server.serve_forever()
-        # print("server finished")
-
-
 class MyHRIE:
     """IF_Server
     """
@@ -941,7 +917,7 @@ class MyHRIE:
 def test_engine(port, engine_profile_file=None, client_info=None, my_engine_urn=None, logger=None):
     """test_engine
     """
-    IF_server(port).run(IF(MyHRIE(), engine_profile_file, client_info, my_engine_urn, logger))
+    IF_server.IF_server(port).run(IF(MyHRIE(), engine_profile_file, client_info, my_engine_urn, logger))
 
 if __name__ == "__main__":
     # コマンドラインでの実行の場合はloggerの指定は厳しい
