@@ -1,6 +1,7 @@
 # Navigation.py
 #
 # Copyright 2019 Ryota Higashi
+# Copyright 2021 Eiichi Inohira
 # This software may be modified and distributed under the terms
 # of the MIT license
 #
@@ -15,16 +16,9 @@ import queue
 import time
 from datetime import datetime
 import threading
+import xmlrpc.client
 
-from pyrois import RoIS_Common, RoIS_HRI
-
-import socketserver
-import xmlrpc.server
-
-class ThreadingXMLRPCServer(socketserver.ThreadingMixIn, xmlrpc.server.SimpleXMLRPCServer):
-    """ThreadingXMLRPCServer
-    """
-    pass
+from pyrois import RoIS_Common, RoIS_HRI, IF_server
 
 
 class Command(RoIS_Common.Command):
@@ -131,9 +125,9 @@ class component:
         self._state = False
 
 
-def event_dispatch(n):
-    """event_dispatch
-    """
+# def event_dispatch(n):
+#     """event_dispatch
+#     """
 
 
 def example_n(port):
@@ -143,15 +137,11 @@ def example_n(port):
     n = Navigation(c)
 
     # start the timer to dispatch events
-    t = threading.Timer(0.1, event_dispatch, args=(n,))
-    t.start()
+    # t = threading.Timer(0.1, event_dispatch, args=(n,))
+    # t.start()
 
     # start the XML-RPC server
-    server = ThreadingXMLRPCServer(("0.0.0.0", port), logRequests=False)
-    server.register_instance(n)
-    server.register_introspection_functions()
-    server.register_multicall_functions()
-    server.serve_forever()
+    IF_server.IF_server(port).run(n)
 
 
 if __name__ == '__main__':
